class Recipe:
    def __init__(self, title, author, picture_url, total_time, prep_time, cook_time, servings, level, ingredients, directions, categories):
       self.title = title
       self.author = author
       self.picture_url = picture_url
       self.total_time = total_time
       self.prep_time = prep_time
       self.cook_time = cook_time
       self.servings = servings
       self.level = level
       self.ingredients = ingredients
       self.directions = directions
       self.categories = categories
